View source: R/resi_asymptotic.R
| resi_pe_asymptotic | R Documentation |
Computes RESI point estimates and asymptotic confidence intervals using either a normal approximation (Zhang et al., 2025) or a quadratic-form (Imhof/Davies) approach.
resi_pe_asymptotic(
model.full,
data,
vcovfunc = sandwich::vcovHC,
coefficients = TRUE,
anova = TRUE,
alpha = 0.05,
ci.method = c("qf", "normal", "cf"),
type = "HC3",
unbiased = TRUE,
Anova.args = list(),
vcov.args = list(),
...
)
model.full |
Fitted |
data |
Data frame of model data. |
vcovfunc |
Variance estimator for RESI point estimates. Default:
|
coefficients |
Logical; include coefficient table. Default |
anova |
Logical; include anova table. Default |
alpha |
Numeric; significance level. Default |
ci.method |
Character; |
type |
Character; HC type for the sandwich variance used in CI
construction (controls tau_i weights in SigmaXw). Default |
unbiased |
Logical; use bias-corrected RESI point estimate. Default
|
Anova.args |
List; additional arguments passed to |
vcov.args |
List; additional arguments passed to |
... |
Ignored. |
A list of class "resi" with coefficients and/or
anova tables containing RESI point estimates and CIs.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.